SamplerPool

Struct SamplerPool 

pub struct SamplerPool<T: PoolLabel + Component + Clone>(pub T);
A component for building sampler pools.

Sampler pools are bevy_seedling’s primary mechanism for playing multiple sounds at once. SamplerPool allows you to precisely define pools and their routing.

Constructing pools

To construct a pool, you’ll need to provide a PoolLabel.

// Note that you'll need a few additional traits to support `PoolLabel`
#[derive(PoolLabel, Debug, Clone, PartialEq, Eq, Hash)]
struct SimplePool;

fn spawn_pool(mut commands: Commands) {
    commands.spawn(SamplerPool(SimplePool));
}

You can also provide an explicit PoolSize, overriding the DefaultPoolSize resource.

commands.spawn((
    SamplerPool(SimplePool),
    // A pool of exactly 16 samplers that cannot grow
    PoolSize(16..=16),
));

Finally, you can insert arbitrary effects.

#[derive(PoolLabel, Debug, Clone, PartialEq, Eq, Hash)]
struct EffectsPool;

commands.spawn((
    SamplerPool(EffectsPool),
    sample_effects![LowPassNode::default(), SpatialBasicNode::default()],
));

By default, pools will insert a volume node in the root SamplerPool entity and connect all its samplers to it. As a result, you can easily route the entire pool with a single connect call.

let filter = commands.spawn(LowPassNode::default()).id();

commands.spawn(SamplerPool(SimplePool)).connect(filter);

Playing samples in a pool

Once you’ve spawned a pool, playing samples in it is easy! Just spawn your sample players with the label.

#[derive(PoolLabel, Debug, Clone, PartialEq, Eq, Hash)]
struct SimplePool;

fn spawn_pool_and_play(mut commands: Commands, server: Res<AssetServer>) {
    commands.spawn(SamplerPool(SimplePool));

    commands.spawn((SimplePool, SamplePlayer::new(server.load("my_sample.wav"))));
}

Pools with effects will automatically insert SampleEffects into queued SamplePlayers.

#[derive(PoolLabel, Debug, Clone, PartialEq, Eq, Hash)]
struct SpatialPool;

commands.spawn((
    SamplerPool(SpatialPool),
    sample_effects![SpatialBasicNode::default()],
));

// Once spawned, this entity will receive a
// `SampleEffects` pointing to a `SpatialBasicNode`
commands.spawn((SpatialPool, SamplePlayer::new(server.load("my_sample.wav"))));

See SampleEffects for more details.

Architecture

Sampler pools are collections of individual sampler nodes, each of which can play a single sample at a time. When samples are queued up for playback, bevy_seedling will look for the best sampler in the corresponding pool. If a suitable sampler is found, the sample will begin playback, otherwise waiting until a slot opens up. If the time spent waiting exceeds a sample’s SampleQueueLifetime, the sample’s playback is considered complete, and the OnComplete effect is applied.

Each sampler node is routed to a final volume node. For a simple pool:

#[derive(PoolLabel, Debug, Clone, PartialEq, Eq, Hash)]
struct SimplePool;

commands.spawn(SamplerPool(SimplePool));

We end up with a graph like:

┌───────┐┌───────┐┌───────┐┌───────┐
│Sampler││Sampler││Sampler││Sampler│
└┬──────┘└┬──────┘└┬──────┘└┬──────┘
┌▽────────▽────────▽────────▽┐
│Volume                      │
└┬───────────────────────────┘
┌▽──────┐
│MainBus│
└───────┘

If a pool includes effects, these are inserted in series with each sampler. For a pool with spatial processing:

commands.spawn((
    SamplerPool(SpatialPool),
    sample_effects![SpatialBasicNode::default()],
));

We end up with a graph like:

┌───────┐┌───────┐┌───────┐┌───────┐
│Sampler││Sampler││Sampler││Sampler│
└┬──────┘└┬──────┘└┬──────┘└┬──────┘
┌▽──────┐┌▽──────┐┌▽──────┐┌▽──────┐
│Spatial││Spatial││Spatial││Spatial│
└┬──────┘└┬──────┘└┬──────┘└┬──────┘
┌▽────────▽────────▽────────▽┐
│Volume                      │
└┬───────────────────────────┘
┌▽──────┐
│MainBus│
└───────┘

Tuple Fields

0: T