pub struct SamplePlayer {
pub sample: Handle<AudioSample>,
pub repeat_mode: RepeatMode,
pub volume: Volume,
}Expand description
A component that queues sample playback.
Playing sounds
Playing a sound is very simple!
fn play_sound(mut commands: Commands, server: Res<AssetServer>) {
commands.spawn(SamplePlayer::new(server.load("my_sample.wav")));
}This queues playback in a SamplerPool.
When no effects are applied, samples are played in the
DefaultPool.
The SamplePlayer component includes two fields that cannot change during
playback: repeat_mode and volume. Because SamplePlayer is immutable,
these can only be changed by re-inserting, which subsequently stops and restarts
playback. To update a sample’s volume dynamically, consider adding a
VolumeNode as an effect.
Lifecycle
By default, entities with a SamplePlayer component are despawned when
playback completes. If you insert SamplePlayer components on gameplay entities
such as the player or enemies, you’ll probably want to set PlaybackSettings::on_complete
to OnComplete::Remove or even OnComplete::Preserve.
#[derive(Component)]
struct Player;
fn play_sound_on_player(
player: Single<Entity, With<Player>>,
server: Res<AssetServer>,
mut commands: Commands,
) {
commands.entity(*player).insert((
SamplePlayer::new(server.load("my_sample.wav")),
PlaybackSettings::default().remove(),
));
}Applying effects
Effects can be applied directly to a sample entity with
SampleEffects.
fn play_with_effects(mut commands: Commands, server: Res<AssetServer>) {
commands.spawn((
SamplePlayer::new(server.load("my_sample.wav")),
sample_effects![
SpatialBasicNode::default(),
LowPassNode { frequency: 500.0 }
],
));
}In the above example, we connect a spatial and low-pass node in series with the sample player. Effects are arranged in the order they’re spawned, so the output of the spatial node is connected to the input of the low-pass node.
When you apply effects to a sample player, the node components are added using the
SampleEffects relationships. If you want to access
the effects in terms of the sample they’re applied to, you can break up your
queries and use the EffectsQuery trait.
commands.spawn((
// We'll look for sample player entities with the name "dynamic"
Name::new("dynamic"),
SamplePlayer::new(server.load("my_sample.wav")),
sample_effects![VolumeNode::default()],
));
fn update_volume(
sample_players: Query<(&Name, &SampleEffects)>,
mut volume: Query<&mut VolumeNode>,
) -> Result {
for (name, effects) in &sample_players {
if name.as_str() == "dynamic" {
// Once we've found the target entity, we can get at
// its effects with `EffectsQuery`
volume.get_effect_mut(effects)?.volume = Volume::Decibels(-6.0);
}
}
Ok(())
}Applying effects directly to a SamplePlayer is simple, but it
has some tradeoffs, so you may
find yourself gravitating towards manually defined SamplerPools as your
requirements grow.
Supporting components
A SamplePlayer can be spawned with a number of components:
- Any component that implements
PoolLabel PlaybackSettingsSamplePrioritySampleQueueLifetimeSampleEffects
Altogether, that would look like:
commands.spawn((
DefaultPool,
SamplePlayer {
sample: server.load("my_sample.wav"),
repeat_mode: RepeatMode::PlayOnce,
volume: Volume::UNITY_GAIN,
},
PlaybackSettings {
play: Notify::new(true),
play_from: PlayFrom::BEGINNING,
speed: 1.0,
on_complete: OnComplete::Despawn,
},
SamplePriority(0),
SampleQueueLifetime(std::time::Duration::from_millis(100)),
sample_effects![SpatialBasicNode::default()],
));Once a sample has been queued in a pool, the Sampler component
will be inserted, which provides information about the
playhead position and playback status.
Fields
sample: Handle<AudioSample>The sample to play.
repeat_mode: RepeatModeSets the sample’s RepeatMode.
Defaults to RepeatMode::PlayOnce.
The RepeatMode can only be configured once at the beginning of playback.
volume: VolumeSets the volume of the sample.
Defaults to Volume::UNITY_GAIN.
This volume can only be configured once at the beginning of playback.
For dynamic volume, consider routing to buses or applying VolumeNode
as an effect.
Implementations
Sourceimpl SamplePlayer
impl SamplePlayer
Sourcepub fn new(handle: Handle<AudioSample>) -> Self
pub fn new(handle: Handle<AudioSample>) -> Self
Construct a new SamplePlayer.
fn play_sound(mut commands: Commands, server: Res<AssetServer>) {
commands.spawn(SamplePlayer::new(server.load("my_sample.wav")));
}This immediately queues up the sample for playback.
Sourcepub fn looping(self) -> Self
pub fn looping(self) -> Self
Enable looping playback.
fn play_sound(mut commands: Commands, server: Res<AssetServer>) {
commands.spawn(SamplePlayer::new(server.load("my_sample.wav")).looping());
}Looping can only be configured once at the beginning of playback.
Sourcepub fn with_volume(self, volume: Volume) -> Self
pub fn with_volume(self, volume: Volume) -> Self
Set the overall sample volume.
fn play_sound(mut commands: Commands, server: Res<AssetServer>) {
commands.spawn(
SamplePlayer::new(server.load("my_sample.wav")).with_volume(Volume::Decibels(-6.0)),
);
}This volume can only be configured once at the beginning of playback.
For dynamic volume, consider routing to buses or applying VolumeNode
as an effect.